pub struct HighResolution;Expand description
Makes this PixelCamera high resolution, disabling the pixelation effect.
The camera will have the same scaling, but the pixels will no longer be locked to the grid. This is useful for when you need to quickly check how the game looks when not locked to the grid.
Note that high resolution sprites (those on the PixelCamera::viewport_layers) will no longer
always be rendered on top of pixel sprites. Make sure your Z values are set correctly.